@@ -9,6 +9,8 @@
 #ifndef __irc_std_h
 #define __irc_std_h
 
+#define _GNU_SOURCE 1
+
 #include "defs.h"
 
 /*
@@ -267,7 +269,7 @@ extern	volatile int    signals_caught[NSIG];
 #define BUILT_IN_COMMAND(x) \
 	void x (const char *command, char *args, const char *subargs)
 
-#define BUILT_IN_KEYBINDING(x) void x (unsigned int key, unsigned char *string)
+#define BUILT_IN_KEYBINDING(x) void x (unsigned int key, char *string)
 
 typedef char Filename[PATH_MAX + 1];
 
@@ -308,9 +310,11 @@ typedef int intptr_t;
 #ifdef PRIdMAX
 # define INTMAX_FORMAT "%" PRIdMAX
 # define UINTMAX_FORMAT "%" PRIuMAX
+# define UINTMAX_HEX_FORMAT "%" PRIxMAX
 #else
 # define INTMAX_FORMAT "%jd"
 # define UINTMAX_FORMAT "%ju"
+# define UINTMAX_HEX_FORMAT "%jx"
 #endif
 
 /*
@@ -348,10 +352,6 @@ typedef		uint32_t		u_32int_t;
 #define howmany(x, y)   (((x) + ((y) - 1)) / (y))
 #endif
 
-#if defined(HAVE_SYS_SYSCTL_H)
-#include <sys/sysctl.h>
-#endif
-
 /*
  * Define an RFC2553 compatable "struct sockaddr_storage" if we do not
  * already have one.
@@ -415,12 +415,6 @@ typedef struct stat		Stat;
 #define VALGRIND_DESTROY_MEMPOOL(x)
 #endif
 
-/*
- * Ah, the joys of newer gcc's....
- */
-#define CUC_PP (const unsigned char **)
-#define CC_PP (const char **)
-
 #ifdef NEWLOCALE_DOESNT_WORK
 #undef HAVE_NEWLOCALE
 #endif
