@@ -19,7 +19,7 @@
 typedef struct InputLine
 {
 	/* The current UTF8 input line (plain old c string */
-	unsigned char	input_buffer[INPUT_BUFFER_SIZE+1];
+	char	input_buffer[INPUT_BUFFER_SIZE+1];
 
 	/* The offset into input_buffer where each logical char starts */
 	int		logical_chars[INPUT_BUFFER_SIZE + 1];
@@ -34,13 +34,13 @@ typedef struct InputLine
 	int		number_of_logical_chars;
 
 	char *		input_prompt_raw;
-	unsigned char *	input_prompt;
+	char *	input_prompt;
 	int		input_prompt_len;
 	int		input_line;
 
-        unsigned char *	ind_left;
+        char *	ind_left;
         int     	ind_left_len;
-        unsigned char *	ind_right;
+        char *	ind_right;
         int     	ind_right_len;
 
 	int		refresh;
@@ -72,7 +72,6 @@ struct	ScreenStru *	next;			/* Previous screen in list */
 	int		input_window;		/* Window that has the input focus */
 	unsigned 	last_window_refnum;	/* The previous input window (for /window back) */
 	Window *	_window_list;		/* The top window on me */
-	Window *	_window_list_end;	/* The bottom window on me */
 	int		visible_windows;	/* Number of windows on me */
 	WindowStack *	window_stack;		/* Number of windows on my stack */
 
@@ -106,25 +105,26 @@ struct	ScreenStru *	next;			/* Previous screen in list */
 	void		add_wait_prompt 		(const char *, void (*)(char *, const char *), const char *, int, int);
 	void		fire_wait_prompt		(u_32int_t);
 	void		fire_normal_prompt		(const char *);
-	void		add_to_screen			(const unsigned char *);
+	void		add_to_screen			(const char *);
 	void		translate_user_input		(unsigned char byte);
 	void		create_new_screen		(void);
 	void		kill_screen			(struct ScreenStru *);
 
-const	unsigned char *	all_off				(void);
-	unsigned char *	new_normalize_string		(const unsigned char *, int, int);
-	unsigned char *	denormalize_string		(const unsigned char *);
-	unsigned char *	normalized_string_to_plain_text (const unsigned char *str);
-	unsigned char **prepare_display			(int, const unsigned char *, int, int *, int);
-	size_t		output_with_count		(const unsigned char *, int, int);
-	void    	add_to_window_scrollback 	(int, const unsigned char *, intmax_t);
+const	char *	all_off				(void);
+		char *	new_normalize_string		(const char *, int, int);
+		char *	denormalize_string		(const char *);
+		char *	normalized_string_to_plain_text (const char *str);
+		char **	prepare_display			(int, const char *, int, int *, int);
+	size_t		output_with_count		(const char *, int, int);
+	void    	add_to_window_scrollback 	(int, const char *, intmax_t);
 
-	unsigned char *	prepare_display2		(const unsigned char *, int, int, char, int);
+	char *	prepare_display2		(const char *, int, int, char, int);
 
-	void		chop_columns 			(unsigned char **, size_t);
-	void		chop_final_columns 		(unsigned char **, size_t);
+	void		chop_columns 			(char **, size_t);
+	void		chop_final_columns 		(char **, size_t);
 
 	int		number_of_windows_on_screen	(struct ScreenStru *);
+	Window *	get_screen_bottom_window	(struct ScreenStru *);
 
 /* Dont do any word-wrapping, just truncate each line at its place. */
 #define PREPARE_NOWRAP	0x01
