@@ -26,8 +26,13 @@
  */
 typedef struct	CryptStru
 {
+/*
+	List	l;
+*/
+/*
 	struct	CryptStru *next;
 	char *	nick;
+*/
 	char *	serv;
 	char *	passwd;
 	int	passwdlen;
@@ -37,13 +42,13 @@ typedef struct	CryptStru
 }	MAY_ALIAS Crypt;
 
 	BUILT_IN_COMMAND(encrypt_cmd);
-	char *	crypt_msg 	(const unsigned char *, Crypt *);
-	char *	decrypt_msg 	(const unsigned char *, Crypt *);
-	Crypt *	is_crypted 	(const char *, int serv, const char *ctcp_type);
+	char *	crypt_msg 	(const char *, List *);
+	char *	decrypt_msg 	(const char *, List *);
+	List *	is_crypted 	(const char *, int serv, const char *ctcp_type);
 
 	/* These are for internal use only -- do not call outside crypt.c */
-	unsigned char *	decipher_message (const unsigned char *, size_t, Crypt *, int *);
-	unsigned char *	cipher_message	(const unsigned char *, size_t, Crypt *, int *);
+	char *	decipher_message (const char *, size_t, List *, int *);
+	char *	cipher_message	(const char *, size_t, List *, int *);
 	char *  sha256str (const char *, size_t, char *);
 	char *  sha256 (const char *, size_t, char *);
 
@@ -60,7 +65,7 @@ typedef struct	CryptStru
 	ssize_t fish_decoder (const char *, size_t, const void *, size_t, char *, size_t);
 #endif
 
-	void     encrypt_sed (unsigned char *, int, const unsigned char *, int);
-	void     decrypt_sed (unsigned char *, int, const unsigned char *, int);
+	void     encrypt_sed (char *, int, const char *, int);
+	void     decrypt_sed (char *, int, const char *, int);
 
 #endif /* _CRYPT_H_ */
