@@ -13,10 +13,6 @@
 /* To get declaration of "output_screen" */
 #include "screen.h"
 
-#ifdef WITH_THREADED_STDOUT
-#include "tio.h"
-#endif
-
 extern	volatile int	need_redraw;
 extern	int	meta_mode;
 
@@ -31,22 +27,13 @@ extern	int	meta_mode;
 
 # ifdef __need_putchar_x__
 __inline__ static int putchar_x (int c) { 
-#  ifdef WITH_THREADED_STDOUT
-	tio_fputc((int)c, tio_stdout);
-	return 1;
-#  else
 	return fputc((int) c, current_ftarget );
-#  endif
 }
 # endif
 
 # ifdef __need_term_flush__
 __inline__ static void term_flush (void) { 
-#  ifdef WITH_THREADED_STDOUT
-	tio_flush(tio_stdout);
-#  else
 	fflush( current_ftarget ); 
-#  endif
 }
 # endif
 #endif
@@ -627,13 +614,10 @@ int	tputs_x(char *);
 #define term_set_background(x)	tputs_x(current_term->TI_backcolors[(x) & 0xff])
 #define term_set_bold_foreground(x)	tputs_x(current_term->TI_bold_forecolors[(x) & 0x07])
 #define term_set_bold_background(x)	tputs_x(current_term->TI_bold_backcolors[(x) & 0x07])
-#define term_set_attribs(f,b)	tputs_x(term_getsgr(TERM_SGR_COLORS,(f),(b)))
-#define term_putgchar(x)	tputs_x(term_getsgr(TERM_SGR_GCHAR,(x),0))
 #define term_clear_screen()	term_clrscr()
 #define term_move_cursor(c, r)	term_gotoxy((c),(r))
 #define term_cr()		tputs_x(current_term->TI_cr)
 #define term_newline()		tputs_x(current_term->TI_nel)
-#define term_cursor_left()	term_left(1)
 #define term_cursor_right()	term_right(1)
 #define term_clear_to_eol()	term_clreol()
 #define term_all_off()          tputs_x(current_term->TI_normal);
@@ -646,18 +630,12 @@ int	tputs_x(char *);
 	BUILT_IN_KEYBINDING(term_pause);
 	void		term_inputline_putchar 	(unsigned char);
 	void		term_scroll 		(int, int, int);
-	void		term_insert 		(unsigned char);
-	void		term_delete 		(int);
-	void		term_repeat		(unsigned char, int);
 	void		term_right		(int);
-	void		term_left		(int);
 	void		term_clreol		(void);
 	void		term_clrscr		(void);
 	void		term_gotoxy		(int, int);
 	void		term_reset		(void);
-	int		term_eight_bit		(void);
-	void		set_term_eight_bit	(int);
-	void		set_meta_8bit		(void *);
+	void		set_automargin_override	(void *);
 	const char *	term_getsgr		(int, int, int);
 	const char *	get_term_capability	(const char *, int, int);
 
