@@ -1115,127 +1115,6 @@ u_32int_t	bsd_arc4random (void)
 }
 #endif
 
-#if 0
-/* ----------------------- start of humanize_number stuff ------------------*/
-/*	$NetBSD: humanize_number.c,v 1.8 2004/07/27 01:56:24 enami Exp $ */ 
-/*
- * Copyright (c) 1997, 1998, 1999, 2002 The NetBSD Foundation, Inc.
- * All rights reserved.
- *
- * This code is derived from software contributed to The NetBSD Foundation
- * by Jason R. Thorpe of the Numerical Aerospace Simulation Facility,
- * NASA Ames Research Center, by Luke Mewburn and by Tomas Svensson.
- *
- * This is licensed under the 4-clause BSD license, which is the 3-clause
- * BSD license (found above) with this clause added:
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *      This product includes software developed by the NetBSD
- *      Foundation, Inc. and its contributors.
- */
-
-/* XXX TODO -- At some point 'bytes' needs to be 64 bits */
-int humanize_number (char *buf, size_t len, long bytes, const char *suffix, int scale, int flags)
-{
-	const char *prefixes, *sep;
-	int	b, i, r, maxscale, s1, s2, sign;
-	/* XXX TODO -- divisor and max need to become 64 bits */
-	long	divisor, max;
-	size_t	baselen;
-
-	if (buf == NULL)
-		return -1;
-	if (suffix == NULL)
-		return -1;
-	if (scale < 0)
-		return -1;
-
-	if (flags & HN_DIVISOR_1000) {
-		/* SI for decimal multiplies */
-		divisor = 1000;
-		if (flags & HN_B)
-			prefixes = "B\0k\0M\0G\0T\0P\0E";
-		else
-			prefixes = "\0\0k\0M\0G\0T\0P\0E";
-	} else {
-		/*
-		 * binary multiplies
-		 * XXX IEC 60027-2 recommends Ki, Mi, Gi...
-		 */
-		divisor = 1024;
-		if (flags & HN_B)
-			prefixes = "B\0K\0M\0G\0T\0P\0E";
-		else
-			prefixes = "\0\0K\0M\0G\0T\0P\0E";
-	}
-
-#define	SCALE2PREFIX(scale)	(&prefixes[(scale) << 1])
-	maxscale = 7;
-
-	if (scale >= maxscale &&
-	    (scale & (HN_AUTOSCALE | HN_GETSCALE)) == 0)
-		return (-1);
-
-	if (buf == NULL || suffix == NULL)
-		return (-1);
-
-	if (len > 0)
-		buf[0] = '\0';
-	if (bytes < 0) {
-		sign = -1;
-		bytes *= -100;
-		baselen = 3;		/* sign, digit, prefix */
-	} else {
-		sign = 1;
-		bytes *= 100;
-		baselen = 2;		/* digit, prefix */
-	}
-	if (flags & HN_NOSPACE)
-		sep = "";
-	else {
-		sep = " ";
-		baselen++;
-	}
-	baselen += strlen(suffix);
-
-	/* Check if enough room for `x y' + suffix + `\0' */
-	if (len < baselen + 1)
-		return (-1);
-
-	if (scale & (HN_AUTOSCALE | HN_GETSCALE)) {
-		/* See if there is additional columns can be used. */
-		for (max = 100, i = len - baselen; i-- > 0;)
-			max *= 10;
-
-		for (i = 0; bytes >= max && i < maxscale; i++)
-			bytes /= divisor;
-
-		if (scale & HN_GETSCALE)
-			return (i);
-	} else
-		for (i = 0; i < scale && i < maxscale; i++)
-			bytes /= divisor;
-
-	/* If a value <= 9.9 after rounding and ... */
-	if (bytes < 995 && i > 0 && flags & HN_DECIMAL) {
-		/* baselen + \0 + .N */
-		if (len < baselen + 1 + 2)
-			return (-1);
-		b = ((int)bytes + 5) / 10;
-		s1 = b / 10;
-		s2 = b % 10;
-		r = snprintf(buf, len, "%d.%d%s%s%s",
-		    sign * s1, s2, sep, SCALE2PREFIX(i), suffix);
-	} else
-		r = snprintf(buf, len, "%lld%s%s%s",
-		    /* LONGLONG */
-		    (long long)(sign * ((bytes + 50) / 100)),
-		    sep, SCALE2PREFIX(i), suffix);
-
-	return (r);
-}
-#endif
-
 /* --------------------------- start of misc stuff -------------------- */
 /* This is written by EPIC Software Labs contributers and is public domain */
 #ifndef HAVE_VSNPRINTF
