@@ -149,10 +149,10 @@
 
 
 #include "irc.h"
+#include "list.h"
 #include "sedcrypt.h"
 #include "ctcp.h"
 #include "ircaux.h"
-#include "list.h"
 #include "output.h"
 #include "vars.h"
 #include "words.h"
@@ -162,25 +162,27 @@
 #endif
 
 #ifdef HAVE_SSL
-static char *	decipher_evp (const unsigned char *passwd, int passwdlen, const unsigned char *ciphertext, int cipherlen, const EVP_CIPHER *type, int *outlen, int ivsize);
+static char *	decipher_evp (const char *passwd, int passwdlen, const char *ciphertext, int cipherlen, const EVP_CIPHER *type, int *outlen, int ivsize);
 #endif
-static char *	decrypt_by_prog (const unsigned char *str, size_t *len, Crypt *crypt);
+static char *	decrypt_by_prog (const char *str, size_t *len, List *crypt);
 
 #ifdef HAVE_SSL
-static char *	cipher_evp (const unsigned char *passwd, int passwdlen, const unsigned char *plaintext, int plaintextlen, const EVP_CIPHER *type, int *retsize, int ivsize);
+static char *	cipher_evp (const char *passwd, int passwdlen, const char *plaintext, int plaintextlen, const EVP_CIPHER *type, int *retsize, int ivsize);
 #endif
-static char *	encrypt_by_prog (const unsigned char *str, size_t *len, Crypt *crypt);
+static char *	encrypt_by_prog (const char *str, size_t *len, List *crypt);
 
 /* This function is used by CTCP handling, but not by xform! */
-unsigned char *	decipher_message (const unsigned char *ciphertext, size_t len, Crypt *crypti, int *retlen)
+char *	decipher_message (const char *ciphertext, size_t len, List *cryptl, int *retlen)
 {
     do
     {
+	Crypt *crypti = (Crypt *)(cryptl->d);
+
 	if (crypti->sed_type == CAST5CRYPT || crypti->sed_type == BLOWFISHCRYPT ||
 	    crypti->sed_type == AES256CRYPT || crypti->sed_type == AESSHA256CRYPT ||
 	    crypti->sed_type == FISHCRYPT)
 	{
-	    unsigned char *	outbuf = NULL;
+	    char *	outbuf = NULL;
 #ifdef HAVE_SSL
 	    const EVP_CIPHER *type;
 	    int	bytes_to_trim;
@@ -247,25 +249,25 @@ unsigned char *	decipher_message (const unsigned char *ciphertext, size_t len, C
 	    outbuf[len - bytes_to_trim] = 0; 
 	    memmove(outbuf, outbuf + ivsize, len - ivsize);
 #endif
-	    return outbuf;
+	    return (char *)outbuf;
 	}
 	else if (crypti->sed_type == SEDCRYPT || crypti->sed_type == SEDSHACRYPT)
 	{
-		unsigned char *	text;
+		char *	text;
 
 		text = new_malloc(len + 1);
 		memmove(text, ciphertext, len);
 		decrypt_sed(text, len, crypti->passwd, crypti->passwdlen);
 		*retlen = len;
-		return text;
+		return (char *)text;
 	}
 	else if (crypti->sed_type == PROGCRYPT)
 	{
-		unsigned char *retval;
+		char *retval;
 
-		retval = decrypt_by_prog(ciphertext, &len, crypti);
+		retval = decrypt_by_prog(ciphertext, &len, cryptl);
 		*retlen = len;
-		return retval;
+		return (char *)retval;
 	}
 	else
 		panic(1, "decipher_message: crypti->sed_type %d is not valid", crypti->sed_type);
@@ -276,8 +278,10 @@ unsigned char *	decipher_message (const unsigned char *ciphertext, size_t len, C
 }
 
 #ifdef HAVE_SSL
-static char *	decipher_evp (const unsigned char *passwd, int passwdlen, const unsigned char *ciphertext, int cipherlen, const EVP_CIPHER *type, int *outlen, int ivsize)
+static char *	decipher_evp (const char *passwd_, int passwdlen, const char *ciphertext_, int cipherlen, const EVP_CIPHER *type, int *outlen, int ivsize)
 {
+	const unsigned char *passwd = (const unsigned char *)passwd_;
+	const unsigned char *ciphertext = (const unsigned char *)ciphertext_;
         unsigned char *outbuf;
 	unsigned char	*iv = NULL;
 	unsigned long errcode;
@@ -320,12 +324,14 @@ static char *	decipher_evp (const unsigned char *passwd, int passwdlen, const un
 
 	if (ivsize > 0)
 		new_free(&iv);
-	return outbuf;
+	return (char *)outbuf;
 }
 #endif
 
-void     decrypt_sed (unsigned char *str, int len, const unsigned char *passwd, int passwdlen)
+void     decrypt_sed (char *str_, int len, const char *passwd_, int passwdlen)
 {
+	unsigned char *str = (unsigned char *)str_;
+const 	unsigned char *passwd = (const unsigned char *)passwd_;
         int	passwd_pos,
                 i;
         char    mix,
@@ -334,7 +340,7 @@ void     decrypt_sed (unsigned char *str, int len, const unsigned char *passwd,
         if (!passwd)
                 return;                 /* no decryption */
 
-        passwdlen = strlen(passwd);
+        passwdlen = strlen((const char *)passwd);
         passwd_pos = 0;
         mix = 0;
 
@@ -348,11 +354,12 @@ void     decrypt_sed (unsigned char *str, int len, const unsigned char *passwd,
         str[i] = (char) 0;
 }
 
-static char *	decrypt_by_prog (const unsigned char *str, size_t *len, Crypt *crypti)
+static char *	decrypt_by_prog (const char *str, size_t *len, List *cryptl)
 {
         char    *ret = NULL, *input;
         char *  args[3];
         int     iplen;
+	Crypt *	crypti = (Crypt *)(cryptl->d);
 
         args[0] = malloc_strdup(crypti->prog);
         args[1] = malloc_strdup("decrypt");
@@ -376,8 +383,10 @@ static char *	decrypt_by_prog (const unsigned char *str, size_t *len, Crypt *cry
 }
 
 /*************************************************************************/
-unsigned char *	cipher_message (const unsigned char *orig_message, size_t len, Crypt *crypti, int *retlen)
+char *	cipher_message (const char *orig_message, size_t len, List *cryptl, int *retlen)
 {
+	Crypt *	crypti = (Crypt *)(cryptl->d);
+
 	if (retlen)
 		*retlen = 0;
 	if (!orig_message || !crypti || !retlen)
@@ -387,7 +396,7 @@ unsigned char *	cipher_message (const unsigned char *orig_message, size_t len, C
 	    crypti->sed_type == FISHCRYPT ||
 	    crypti->sed_type == AES256CRYPT || crypti->sed_type == AESSHA256CRYPT)
 	{
-	    unsigned char *ciphertext = NULL;
+	    char *ciphertext = NULL;
 #ifdef HAVE_SSL
 	    size_t	ivlen;
 	    const EVP_CIPHER *type;
@@ -423,25 +432,25 @@ unsigned char *	cipher_message (const unsigned char *orig_message, size_t len, C
 		return NULL;
 	    }
 #endif
-	    return ciphertext;
+	    return (char *)ciphertext;
 	}
 	else if (crypti->sed_type == SEDCRYPT || crypti->sed_type == SEDSHACRYPT)
 	{
-		unsigned char *	ciphertext;
+		char *	ciphertext;
 
 		ciphertext = new_malloc(len + 1);
 		memmove(ciphertext, orig_message, len);
 		encrypt_sed(ciphertext, len, crypti->passwd, strlen(crypti->passwd));
 		*retlen = len;
-		return ciphertext;
+		return (char *)ciphertext;
 	}
 	else if (crypti->sed_type == PROGCRYPT)
 	{
-		unsigned char *ciphertext;
+		char *ciphertext;
 
-		ciphertext = encrypt_by_prog(orig_message, &len, crypti);
+		ciphertext = encrypt_by_prog(orig_message, &len, cryptl);
 		*retlen = len;
-		return ciphertext;
+		return (char *)ciphertext;
 	}
 	else
 		panic(1, "cipher_message: crypti->sed_type %d is not valid", crypti->sed_type);
@@ -450,8 +459,10 @@ unsigned char *	cipher_message (const unsigned char *orig_message, size_t len, C
 }
 
 #ifdef HAVE_SSL
-static char *	cipher_evp (const unsigned char *passwd, int passwdlen, const unsigned char *plaintext, int plaintextlen, const EVP_CIPHER *type, int *retsize, int ivsize)
+static char *	cipher_evp (const char *passwd_, int passwdlen, const char *plaintext_, int plaintextlen, const EVP_CIPHER *type, int *retsize, int ivsize)
 {
+	const unsigned char *passwd = (const unsigned char *)passwd_;
+	const unsigned char *plaintext = (const unsigned char *)plaintext_;
         unsigned char *outbuf;
         int     outlen = 0;
 	int	extralen = 0;
@@ -509,12 +520,14 @@ static char *	cipher_evp (const unsigned char *passwd, int passwdlen, const unsi
 	*retsize = outlen + ivsize;
 	if (iv)
 		new_free(&iv);		/* XXX Is this correct? */
-	return outbuf;
+	return (char *)outbuf;
 }
 #endif
 
-void     encrypt_sed (unsigned char *str, int len, const unsigned char *passwd, int passwd_len)
+void     encrypt_sed (char *str_, int len, const char *passwd_, int passwd_len)
 {
+	unsigned char *str = (unsigned char *)str_;
+	unsigned char *passwd = (unsigned char *)passwd_;
         int     passwd_pos,
                 i;
         char    mix, 
@@ -523,7 +536,7 @@ void     encrypt_sed (unsigned char *str, int len, const unsigned char *passwd,
         if (!passwd)
                 return;                 /* no encryption */
 
-        passwd_len = strlen(passwd);
+        passwd_len = strlen((char *)passwd);
         passwd_pos = 0;
         mix = 0;
 
@@ -537,11 +550,12 @@ void     encrypt_sed (unsigned char *str, int len, const unsigned char *passwd,
         str[i] = (char) 0;
 }
 
-static char *	encrypt_by_prog (const unsigned char *str, size_t *len, Crypt *crypti)
+static char *	encrypt_by_prog (const char *str, size_t *len, List *cryptl)
 {
         char    *ret = NULL, *input;
         char *  args[3];
         int     iplen;
+	Crypt *	crypti = (Crypt *)(cryptl->d);
 
         args[0] = malloc_strdup(crypti->prog);
         args[1] = malloc_strdup("encrypt");
@@ -561,7 +575,7 @@ static char *	encrypt_by_prog (const unsigned char *str, size_t *len, Crypt *cry
 
         new_realloc((void**)&ret, 1+*len);
         ret[*len] = 0;
-        return ret;
+        return (char *)ret;
 }
 
 /**************************************************************************/
@@ -602,8 +616,9 @@ static void	copy_passwd (const char *orig, size_t orig_len, char **passwd, size_
 ssize_t	x ## _encoder (const char *orig, size_t orig_len, const void *meta, size_t meta_len, char *dest, size_t dest_len) \
 { 									\
 	int	retsize = 0; 						\
-	char *	retval; 						\
-	char *	realpasswd;						\
+	char *	retval; 					\
+	char *realpasswd;					\
+	char *	realpasswd_;						\
 	size_t	realpasswdlen;						\
 									\
 	if (orig_len == 0) 						\
@@ -612,7 +627,8 @@ ssize_t	x ## _encoder (const char *orig, size_t orig_len, const void *meta, size
 		return 0; 						\
 	} 								\
 									\
-	make_passwd (meta, meta_len, &realpasswd, &realpasswdlen);	\
+	make_passwd (meta, meta_len, &realpasswd_, &realpasswdlen);	\
+	realpasswd = (char *)realpasswd_;			\
 	retval = cipher_evp(realpasswd, realpasswdlen, orig, orig_len,	\
 				y (), &retsize, ivsize); 		\
 	if (retval && retsize > 0) 					\
@@ -636,10 +652,11 @@ ssize_t	x ## _encoder (const char *orig, size_t orig_len, const void *meta, size
 									\
 ssize_t	x ## _decoder (const char *ciphertext, size_t len, const void *meta, size_t meta_len, char *dest, size_t dest_len) \
 { 									\
-	unsigned char *	outbuf = NULL; 					\
+	char *	outbuf = NULL; 					\
 	int	bytes_to_trim = 0;					\
 	int 	retlen = 0; 						\
-	char *	realpasswd;						\
+	char *	realpasswd_;						\
+	char *realpasswd;					\
 	size_t	realpasswdlen;						\
 									\
 	if (len == 0)							\
@@ -648,7 +665,8 @@ ssize_t	x ## _decoder (const char *ciphertext, size_t len, const void *meta, siz
 		return 0; 						\
 	}								\
 									\
-	make_passwd (meta, meta_len, &realpasswd, &realpasswdlen);	\
+	make_passwd (meta, meta_len, &realpasswd_, &realpasswdlen);	\
+	realpasswd = (char *)realpasswd_;			\
 	if (!(outbuf = decipher_evp(realpasswd, realpasswdlen, ciphertext, len, \
 				y (), &retlen, ivsize))) 		\
 	{ 								\
