@@ -471,8 +471,7 @@ BUILT_IN_COMMAND(fe)
 		*vars,
 		*var[255],
 		*todo = NULL;
-	unsigned	ind, x, y;
-	int     old_display;
+	unsigned	ind, y;
 	int	doing_fe = !strcmp(command, "FE");
 	char	*mapvar = NULL;
 	const char	*mapsep = doing_fe ? space : empty_string;
@@ -538,7 +537,7 @@ BUILT_IN_COMMAND(fe)
 
 	will_catch_break_exceptions++;
 	will_catch_continue_exceptions++;
-	for ( x = 0 ; templist && *templist; )
+	for ( ; templist && *templist; )
 	{
 		for ( y = 0 ; y < ind ; y++ )
 		{
@@ -553,18 +552,19 @@ BUILT_IN_COMMAND(fe)
 			else
 			{
 				int		codepoint;
-				unsigned char 	fec_buffer[16], *word = fec_buffer;
-				
-				if ((codepoint = next_code_point((const unsigned char **)&templist, 0)) < 0)
+				char 		utf8buffer[16];
+				ptrdiff_t	offset;
+
+				if ((codepoint = next_code_point2(templist, &offset, 0)) < 0)
 				{
 					templist++;
 					continue /* What to do? */;
 				}
-				ucs_to_utf8(codepoint, word, 16);
-				add_local_alias(var[y], word, 0);
+				templist += offset;
+				ucs_to_utf8(codepoint, utf8buffer, 16);
+				add_local_alias(var[y], utf8buffer, 0);
 			}
 		}
-		x += ind;
 		runcmds(todo, subargs);
 
 		if (mapvar)
