@@ -40,19 +40,19 @@
 /*
  * irc_version is what $J returns, its the common-name for the version.
  */
-const char irc_version[] = "EPIC5-2.1.10";
-const char useful_info[] = "epic5 2 1 10";
+const char irc_version[] = "EPIC5-2.1.11";
+const char useful_info[] = "epic5 2 1 11";
 
 /*
  * internal_version is what $V returns, its the integer-id for the
  * version, and corresponds to the date of release, YYYYMMDD.
  */ 
-const char internal_version[] = "20220522";
+const char internal_version[] = "20220605";
 
 /*
  * In theory, this number is incremented for every commit.
  */
-const unsigned long	commit_id = 2059;
+const unsigned long	commit_id = 2071;
 
 /*
  * As a way to poke fun at the current rage of naming releases after
@@ -60,7 +60,7 @@ const unsigned long	commit_id = 2059;
  * reality, I have decided to start doing that with EPIC.  These names
  * are intentionally and maliciously silly.  Complaints will be ignored.
  */
-const char ridiculous_version_name[] = "Casuistry";
+const char ridiculous_version_name[] = "Adynaton";
 
 #define __need_putchar_x__
 #include "status.h"
@@ -205,7 +205,7 @@ const char	empty_string[] = "",		/* just an empty string */
 		star[] = "*",
 		dot[] = ".",
 		comma[] = ",";
-unsigned char	*cut_buffer = (unsigned char *) 0;	/* global cut_buffer */
+char	*cut_buffer = (char *) 0;	/* global cut_buffer */
 
 static		char	switch_help[] =
 "Usage: epic [switches] [nickname] [server list]                      \n\
@@ -488,7 +488,6 @@ static	void	parse_args (int argc, char **argv)
 	const char *cptr = NULL;
 	const char *tmp_hostname = NULL;
 	char *the_path = NULL;
-	int size;
 
 	int altargc = 0;
 	char **altargv;
@@ -621,12 +620,7 @@ static	void	parse_args (int argc, char **argv)
 			|| strchr(argv[1], ' ') != NULL 
 			|| strchr(argv[1], '\t') != NULL))
 	{
-		int 	argn, 
-			i,
-			j,
-			c = 0, 
-			n;
-		size_t	len;
+		int 	argn;
 
 		altargv = new_malloc(sizeof(char *));
 		altargv[0] = malloc_strdup(argv[0]);
