@@ -145,7 +145,6 @@ void	set_ssl_root_certs_location (void *stuff)
 	struct stat 	st;
 	VARIABLE *	v;
 	const char *	p;
-	Filename	path;
 
 	if (x_debug & DEBUG_SSL)
 		yell("SSL >>> HERE WE GO -- SETTING SSL ROOT CERTS LOCATION");
@@ -395,7 +394,6 @@ static ssl_info *	get_ssl_info (int vfd)
 static ssl_info *	new_ssl_info (int vfd)
 {
 	ssl_info *x;
-	int	i;
 
 	if (!(x = get_ssl_info(vfd)))
 	{
@@ -796,7 +794,7 @@ int	ssl_connected (int vfd)
 	ssl_info *	x;		/* EPIC info about the conn */
 	unsigned char 	h[256];		/* A place for X509_digest() to write */
 	unsigned	hlen;		/* How big digest in 'h' is */
-	unsigned char	htext[1024];	/* A human readable version of 'h' */
+	char		htext[1024];	/* A human readable version of 'h' */
 	unsigned	i;		/* How many bytes in 'h' we converted */
 
 	/*
@@ -1113,9 +1111,7 @@ int	get_ssl_most_serious_error (int vfd)
  */
 static char *	internal_get_x509_sans (X509 *const cert)
 {
-	int		success = 0;
 	GENERAL_NAMES *	names = NULL;
-	unsigned char *	utf8 = NULL;
 	int		i, count;
 	char *		retval = NULL;
 	size_t		rvclue = 0;
@@ -1176,7 +1172,6 @@ static char *	internal_get_x509_sans (X509 *const cert)
 		if (entry->type == GEN_DNS)
 		{
 			int 	len1;
-			size_t	len2;
 			unsigned char *utf8 = NULL;
 
 			/*
@@ -1192,7 +1187,7 @@ static char *	internal_get_x509_sans (X509 *const cert)
 			     * that's an invalid value, and we declare shenanigans.
 			     */
 			    if ((size_t)len1 == strlen((const char *)utf8))
-				malloc_strcat_word_c(&retval, space, utf8, DWORD_NO, &rvclue);
+				malloc_strcat_word_c(&retval, space, (const char *)utf8, DWORD_NO, &rvclue);
 			}
 
 			if (utf8)
