@@ -677,9 +677,6 @@ static const	int	numcaps = sizeof tcaps / sizeof tcaps[0];
 static	int	term_echo_flag = 1;
 static	int	li;
 static	int	co;
-static	char	termcap[2048];		/* Bigger than we need, just in case */
-static	char	termcap2[2048];		/* Bigger than we need, just in case */
-static	char *	tptr = termcap2;
 
 static	void	term_establish_last_column (void);
 static void	term_enable_last_column (void);
@@ -1652,9 +1649,9 @@ const char *	term_getsgr (int opt, int fore, int back)
 	return (ret);
 }
 
-static char *	control_mangle (unsigned char *text)
+static char *	control_mangle (char *text)
 {
-static 	unsigned char	retval[256];
+static 	char	retval[256];
 	int 	pos = 0;
 	
 	*retval = 0;
@@ -1663,12 +1660,12 @@ static 	unsigned char	retval[256];
 		
 	for (; *text && (pos < 254); text++, pos++)
 	{
-		if (*text < 32) 
+		if ((unsigned char)*text < 32) 
 		{
 			retval[pos++] = '^';
 			retval[pos] = *text + 64;
 		}
-		else if (*text == 127)
+		else if ((unsigned char)*text == 127)
 		{
 			retval[pos++] = '^';
 			retval[pos] = '?';
