@@ -43,6 +43,7 @@
 #include "lastlog.h"
 #include "log.h"
 #include "hook.h"
+#include "list.h"
 #include "sedcrypt.h"
 #include "notify.h"
 #include "vars.h"
@@ -697,7 +698,7 @@ int 	set_variable (const char *name, IrcVariable *var, const char *new_value, in
 {
 	char	*rest;
 	int	changed = 0;
-	unsigned char	*value;
+	char	*value;
 	int	retval = 0;
 
 	if (new_value)
@@ -724,6 +725,7 @@ int 	set_variable (const char *name, IrcVariable *var, const char *new_value, in
 	    case CHAR_VAR:
 	    {
 		int	codepoint;
+		ptrdiff_t	offset;
 
 		if (!value || !*value)
 		{
@@ -732,7 +734,7 @@ int 	set_variable (const char *name, IrcVariable *var, const char *new_value, in
 			break;
 		}
 
-		if ((codepoint = next_code_point((const unsigned char **)&value, 0)) == -1)
+		if ((codepoint = next_code_point2(value, &offset, 1)) == -1)
 		{
 			say("New value of %s could not be determined", name);
 			retval = -1;
@@ -1143,10 +1145,10 @@ const 	VARIABLE *data;
 			break;
 		case CHAR_VAR:
 		{
-			unsigned char utf8str[16];
+			char utf8str[16];
 
 			ucs_to_utf8(data->integer, utf8str, sizeof(utf8str));
-			ret = malloc_strdup(utf8str);
+			ret = malloc_strdup((const char *)utf8str);
 			break;
 		}
 		default:
