@@ -215,39 +215,38 @@ int	codepoint_numcolumns (int ucs)
 }
 
 /* *** ADDED STUFF - NOT IN ORIGINAL *** */
-
-int     next_code_point (const unsigned char **i, int resync)
+int     next_code_point2 (const char *i_, ptrdiff_t *bytes_used, int resync)
 {
-        int     offset;
-        unsigned char    a, b, c, d;
-        const unsigned char *str;
-        int     result;
+        unsigned char   a, b, c, d;
+	const char *	i = i_;
+        const char *	str;
+        int     	result;
 
-	if (!i || !*i)
+	if (!i_)
 		return 0;	/* What is this? */
 
     /* Keep skipping bytes until we find one that works */
-    for (; (**i); (*i)++)
+    for (; *i; i++)
     {
-        str = *i;
+        str = i;
         a = b = c = d = 0;
 	result = -1;
 
 	/* Forcibly refuse to walk past the nul */
-	if (!str[0])
+	if (str[0] == 0)
 		return 0;
 
         if (str[0])
         {
-                a = str[0];
+                a = (unsigned char)str[0];
                 if (str[1])
                 {
-                        b = str[1];
+                        b = (unsigned char)str[1];
                         if (str[2])
                         {
-                                c = str[2];
+                                c = (unsigned char)str[2];
                                 if (str[3])
-                                        d = str[3];
+                                        d = (unsigned char)str[3];
                         }
                 }
         }
@@ -255,7 +254,7 @@ int     next_code_point (const unsigned char **i, int resync)
         if ((a & 0x80) == 0x00)
         {
                 result = a;
-                (*i)++;
+                i++;
         }
 
         /* The 2 high bits are set only?  -- 2 bytes */
@@ -264,7 +263,7 @@ int     next_code_point (const unsigned char **i, int resync)
                 if ((b & 0xC0) == 0x80)
                 {
                         result = ((a & 0x1F) << 6) + (b & 0x3f);
-                        (*i) += 2;;
+                        i += 2;
                 }
         }
 
@@ -278,7 +277,7 @@ int     next_code_point (const unsigned char **i, int resync)
                     result = ((a & 0x0F) << 12) + 
 				((b & 0x3f) << 6) + 
 				(c & 0x3f);
-                    (*i) += 3;
+                    i += 3;
                   }
 		}
         }
@@ -296,7 +295,7 @@ int     next_code_point (const unsigned char **i, int resync)
 				((b & 0x3f) << 12) + 
 				((c & 0x3f) << 6) + 
 				(d & 0x3F);
-                      (*i) += 4;
+                      i += 4;
                     }
 		  }
 		}
@@ -309,11 +308,13 @@ int     next_code_point (const unsigned char **i, int resync)
 			continue;
 	}
 
+	*bytes_used = i - i_;
         return result;
 
     }
 
     /* If we hit the end of the string, return nul */
+    *bytes_used = i - i_;
     return 0;
 }
 
@@ -329,27 +330,26 @@ int     next_code_point (const unsigned char **i, int resync)
  *	0	- I don't see anything wrong with 'i'
  *	-1	- 'i' does not point at a valid utf8 sequence at all.
  */
-int     partial_code_point (const unsigned char *i)
+int     partial_code_point (const char *i_)
 {
-        int     offset;
+	const char *i = i_;
         unsigned char    a, b, c, d;
-        const unsigned char *str;
-        int     result = -1;
+        const char *str;
 
         str = i;
         a = b = c = d = 0;
 
         if (str[0])
         {
-                a = str[0];
+                a = (unsigned char)str[0];
                 if (str[1])
                 {
-                        b = str[1];
+                        b = (unsigned char)str[1];
                         if (str[2])
                         {
-                                c = str[2];
+                                c = (unsigned char)str[2];
                                 if (str[3])
-                                        d = str[3];
+                                        d = (unsigned char)str[3];
                         }
                 }
         }
@@ -439,10 +439,11 @@ int     partial_code_point (const unsigned char *i)
 }
 
 
-int	grab_codepoint (const unsigned char *x)
+int	grab_codepoint (const char *x)
 {
-	const unsigned char *str = x;
-	return next_code_point(&str, 1);
+	ptrdiff_t	offset;
+
+	return next_code_point2(x, &offset, 1);
 }
 
 /*
@@ -464,16 +465,18 @@ int	grab_codepoint (const unsigned char *x)
  *	new_normalize_string() and output_with_count().
  */
 /* XXX DO NOT USE THIS FUNCTION IF 'str' MIGHT CONTAIN HIGHLIGHT CHARS! XXX */
-int	quick_display_column_count (const unsigned char *str)
+int	quick_display_column_count (const char *str)
 {
-	const unsigned char *s;
+	const char *s;
 	int	code_point;
 	int	length = 0;
 	int	x;
+	ptrdiff_t	offset;
 
 	s = str;
-	while ((code_point = next_code_point(&s, 1)))
+	while ((code_point = next_code_point2(s, &offset, 1)))
 	{
+		s += offset;
 		if ((x = codepoint_numcolumns(code_point)) == -1)
 			x = 0;
 		length += x;
@@ -497,18 +500,19 @@ int	quick_display_column_count (const unsigned char *str)
  *      This is used by $regmatches() to convert a pointer to something
  *      that you can pass to $mid().
  */
-int	count_initial_codepoints (const unsigned char *str, const unsigned char *p)
+int	count_initial_codepoints (const char *str, const char *p)
 {
-	const unsigned char *s;
+	const char *s;
 	int	length = 0;
-	int	x;
+	ptrdiff_t	offset;
 
 	if (str >= p)
 		return 0;
 
 	s = str;
-	while (next_code_point(&s, 1))
+	while (next_code_point2(s, &offset, 1))
 	{
+		s += offset;
 		length++;
 		if (s >= p)
 			return length;
@@ -524,16 +528,18 @@ int	count_initial_codepoints (const unsigned char *str, const unsigned char *p)
 }
 
 
-int	input_column_count (const unsigned char *str)
+int	input_column_count (const char *str)
 {
-	const unsigned char *s;
+	const char *s;
 	int	code_point;
 	int	length = 0;
 	int	x;
+	ptrdiff_t	offset;
 
 	s = str;
-	while ((code_point = next_code_point(&s, 1)))
+	while ((code_point = next_code_point2(s, &offset, 1)))
 	{
+		s += offset;
 		if ((x = codepoint_numcolumns(code_point)) == -1)
 			x = 1;
 		length += x;
@@ -549,19 +555,20 @@ int	input_column_count (const unsigned char *str)
  *	0xC0-0xFF
  * This function doesn't attempt to validate broken utf8.
  */
-int	quick_code_point_count (const unsigned char *str)
+int	quick_code_point_count (const char *str)
 {
-	const unsigned char *s;
+	const char *s;
 	int	count;
 
 	for (count = 0, s = str; *s; s++)
 	{
-		if (*s < 0x80 || *s >= 0xC0)
+		if ((unsigned char)*s < 0x80 || (unsigned char)*s >= 0xC0)
 			count++;
 	}
 	return count;
 }
 
+
 /*
  * previous_code_point	- Move *i back one code point.
  *			 *** IMPORTANT ***
@@ -573,44 +580,57 @@ int	quick_code_point_count (const unsigned char *str)
  *	i	A pointer to the start of a CP.
  *
  * Return Value:
- *	- If *i points at the first byte of a code point, then 
- *	  the code point that ends at the byte *i - 1.
- *	- If *i does not point at the first byte of a code point,
- *	  then the code that that contains *i.
- *	- If *i points at the start of string (st), returns 0 so you can stop.
- *	In both cases, *i is moved to the first byte of the code
- *	point whose value is returned.
+ *	- If 'i' points at the first byte of a code point, then 
+ *	  the code point that ends at the byte i - 1.
+ *	- If 'i' does not point at the first byte of a code point,
+ *	  then the code that that contains 'i'.
+ *	- If 'i' points at the start of string (st), returns 0 so you can stop.
+ *	*offset will be set to first byte of the code point whose value is returned.
+ *
+ *	If the previous code point is invalid (next_code_point2() returns -1)
+ *	then it will skip that invalid code point and keep walking backwards.
  */
-int     previous_code_point (const unsigned char *st, const unsigned char **i)
+int     previous_code_point2 (const char *st, const char *i, ptrdiff_t *offset)
 {
-	const unsigned char *	c;
+	const char *	c;
+	int		retval;
+	ptrdiff_t	offset2;
 
-	c = *i;
-	if (c == st)
-		return 0;		/* Time to stop */
+	c = i;
+	for (;;)
+	{
+		if (c == st)
+		{
+			*offset = 0;
+			return 0;		/* Time to stop */
+		}
 
-	if (c > st && (*c < 0x80 || *c >= 0xC0))
-		c--;
+		if (c > st && ((unsigned char)*c < 0x80 || (unsigned char)*c >= 0xC0))
+			c--;
 
-	while (c > st && (*c >= 0x80 && *c < 0xC0))
-		c--;
+		while (c > st && ((unsigned char)*c >= 0x80 && (unsigned char)*c < 0xC0))
+			c--;
 
-	*i = c;
-	return next_code_point(&c, 1);
+		if ((retval = next_code_point2(c, &offset2, 0)) >= 0)
+		{
+			*offset = c - i;
+			return retval;
+		}
+	}
 }
 
 
 /*
  * This does a QUICK count of the CP "index" of 'loc' in 'str'.
  */
-int	quick_code_point_index (const unsigned char *str, const unsigned char *loc)
+int	quick_code_point_index (const char *str, const char *loc)
 {
-	const unsigned char *s;
+	const char *s;
 	int	count;
 
 	for (count = 0, s = str; *s && s < loc; s++)
 	{
-		if (*s < 0x80 || *s >= 0xC0)
+		if ((unsigned char)*s < 0x80 || (unsigned char)*s >= 0xC0)
 			count++;
 	}
 	return count;
