@@ -63,30 +63,30 @@
 /*
  * search() looks for a character forward or backward from mark 
  */
-char *	search_for (char *start, char **mark, char *chars, int how)
+ptrdiff_t	search_for (char *start, char *mark, const char *chars, int how, int *found)
 {
-	const unsigned char *s, *p;
-	size_t	cpoffset = SIZE_MAX;
+	size_t		cpoffset = SIZE_MAX;
+	ptrdiff_t	offset;
 
-	if (!mark)
-		return NULL;		/* Take THAT! */
-        if (!*mark)
-                *mark = start;
-
-	s = *mark;
-	p = chars;
+	if (mark == NULL)
+	{
+		*found = 0;
+		return 0;
+	}
 
         if (how > 0)   /* forward search */
-		s = cpindex(s, p, how, &cpoffset);
+		offset = cpindex2(mark, chars, how, &cpoffset, found);
 
 	else if (how == 0)
-		return NULL;
+		*found = 0;
 
 	else  /* how < 0 */
-		s = rcpindex(s + strlen(s), start, p, -how, &cpoffset);
+		offset = rcpindex2(mark, start, chars, -how, &cpoffset, found);
 
-	*mark = (char *)(intptr_t)s;
-	return *mark;
+	if (*found)
+		return offset;
+	else
+		return 0;
 }
 
 /*
@@ -828,13 +828,12 @@ char *	real_extract (char *start, int firstword, int lastword, int extended)
 	if (firstword == EOS)
 	{
 		mark = start + strlen(start);
-		move_word_rel(start, (const char **)&mark, -1, extended, "\"");
+		move_word_rel(start, &mark, -1, extended, "\"");
 	}
 
 	/* If the firstword is positive, move to that word */
 	else if (firstword >= 0)
-		real_move_to_abs_word(start, (const char **)&mark, 
-					firstword, extended, "\"");
+		real_move_to_abs_word(start, &mark, firstword, extended, "\"");
 
 	/* Its negative.  Hold off right now. */
 	else
@@ -852,8 +851,7 @@ char *	real_extract (char *start, int firstword, int lastword, int extended)
 	else 
 	{
 		if (lastword >= 0)
-			real_move_to_abs_word(start, (const char **)&mark2, 
-						lastword+1, extended, "\"");
+			real_move_to_abs_word(start, &mark2, lastword+1, extended, "\"");
 		else
 			/* its negative -- thats not valid */
 			return malloc_strdup(empty_string);
